#[non_exhaustive]pub enum Event<'a> {
Readable(&'a [u8]),
Tick {
elapsed: Duration,
},
Host(HostRequest<'a>),
}Expand description
An input to the protocol core.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Readable(&'a [u8])
One link-layer frame was read from the device.
Tick
Logical time advanced by elapsed since the last tick (drives poll
cadence and resource timers without a real clock in the core).
Host(HostRequest<'a>)
A request from the host application.